AggregateOp

Enum AggregateOp 

pub enum AggregateOp {
Show 22 variants Argmax, Argmin, Average, Ci0, Ci1, Count, Distinct, Max, Mean, Median, Min, Missing, Q1, Q3, Stderr, Stdev, Stdevp, Sum, Valid, Values, Variance, Variancep,
}
Aggregation function for the field (e.g., mean, sum, median, min, max, count).

Default value: undefined (None)

An aggregate operation to perform on the field prior to sorting (e.g., "count", "mean" and "median"). This property is required in cases where the sort field and the data reference field do not match. The input data objects will be aggregated, grouped by the encoded data field.

For a full list of operations, please see the documentation for aggregate.

The aggregation operations to apply to the fields, such as sum, average or count. See the full list of supported aggregation operations for more information.

Variants



Argmax



Argmin



Average



Ci0



Ci1



Count



Distinct



Max



Mean



Median



Min



Missing



Q1



Q3



Stderr



Stdev



Stdevp



Sum



Valid



Values



Variance



Variancep