Op

Enum Op 

pub enum Op {
Show 33 variants Argmax, Argmin, Average, Ci0, Ci1, Count, CumeDist, DenseRank, Distinct, FirstValue, Lag, LastValue, Lead, Max, Mean, Median, Min, Missing, NthValue, Ntile, PercentRank, Q1, Q3, Rank, RowNumber, Stderr, Stdev, Stdevp, Sum, Valid, Values, Variance, Variancep,
}
The window or aggregation operations to apply within a window, including rank, lead, sum, average or count. See the list of all supported operations here.

Aggregation function for the field (e.g., mean, sum, median, min, max, count).

Default value: undefined (None)

An aggregate operation to perform on the field prior to sorting (e.g., "count", "mean" and "median"). This property is required in cases where the sort field and the data reference field do not match. The input data objects will be aggregated, grouped by the encoded data field.

For a full list of operations, please see the documentation for aggregate.

The aggregation operations to apply to the fields, such as sum, average or count. See the full list of supported aggregation operations for more information.

Variants



Argmax



Argmin



Average



Ci0



Ci1



Count



CumeDist



DenseRank



Distinct



FirstValue



Lag



LastValue



Lead



Max



Mean



Median



Min



Missing



NthValue



Ntile



PercentRank



Q1



Q3



Rank



RowNumber



Stderr



Stdev



Stdevp



Sum



Valid



Values



Variance



Variancep