pub enum ScaleRange {
String(String),
UnionArray(Vec<PrecisionValue>),
}Expand description
The range of the scale. One of:
-
A string indicating a pre-defined named scale range (e.g., example,
"symbol", or"diverging"). -
For continuous scales, two-element array indicating minimum and maximum values, or an array with more than two entries for specifying a piecewise scale.
-
For discrete and discretizing scales, an array of desired output values.
Notes:
-
For sequential, ordinal, and discretizing color scales, you can also specify a color
schemeinstead ofrange. -
Any directly specified
rangeforxandychannels will be ignored. Range can be customized via the view’s corresponding size (widthandheight) or via range steps and paddings properties for band and point scales.
Variants
String(String)
UnionArray(Vec<PrecisionValue>)