TimeUnit

Enum TimeUnit 

pub enum TimeUnit {
Show 44 variants Date, Day, Hours, Hoursminutes, Hoursminutesseconds, Milliseconds, Minutes, Minutesseconds, Month, Monthdate, Quarter, Quartermonth, Seconds, Secondsmilliseconds, Utcdate, Utcday, Utchours, Utchoursminutes, Utchoursminutesseconds, Utcmilliseconds, Utcminutes, Utcminutesseconds, Utcmonth, Utcmonthdate, Utcquarter, Utcquartermonth, Utcseconds, Utcsecondsmilliseconds, Utcyear, Utcyearmonth, Utcyearmonthdate, Utcyearmonthdatehours, Utcyearmonthdatehoursminutes, Utcyearmonthdatehoursminutesseconds, Utcyearquarter, Utcyearquartermonth, Year, Yearmonth, Yearmonthdate, Yearmonthdatehours, Yearmonthdatehoursminutes, Yearmonthdatehoursminutesseconds, Yearquarter, Yearquartermonth,
}
Time unit for the field to be filtered.

Time unit (e.g., year, yearmonth, month, hours) for a temporal field. or a temporal field that gets casted as ordinal.

Default value: undefined (None)

The timeUnit.

Variants



Date



Day



Hours



Hoursminutes



Hoursminutesseconds



Milliseconds



Minutes



Minutesseconds



Month



Monthdate



Quarter



Quartermonth



Seconds



Secondsmilliseconds



Utcdate



Utcday



Utchours



Utchoursminutes



Utchoursminutesseconds



Utcmilliseconds



Utcminutes



Utcminutesseconds



Utcmonth



Utcmonthdate



Utcquarter



Utcquartermonth



Utcseconds



Utcsecondsmilliseconds



Utcyear



Utcyearmonth



Utcyearmonthdate



Utcyearmonthdatehours



Utcyearmonthdatehoursminutes



Utcyearmonthdatehoursminutesseconds



Utcyearquarter



Utcyearquartermonth



Year



Yearmonth



Yearmonthdate



Yearmonthdatehours



Yearmonthdatehoursminutes



Yearmonthdatehoursminutesseconds



Yearquarter



Yearquartermonth