DateTime

Struct DateTime 

pub struct DateTime {
    pub date: Option<f64>,
    pub day: Option<Day>,
    pub hours: Option<f64>,
    pub milliseconds: Option<f64>,
    pub minutes: Option<f64>,
    pub month: Option<Month>,
    pub quarter: Option<f64>,
    pub seconds: Option<f64>,
    pub utc: Option<bool>,
    pub year: Option<f64>,
}
Object for defining datetime in Vega-Lite Filter. If both month and quarter are provided, month has higher precedence. day cannot be combined with other date. We accept string for month and day names.

Fields

date: Option<f64>

Integer value representing the date from 1-31.

day: Option<Day>

Value representing the day of a week. This can be one of: (1) integer value – 1 represents Monday; (2) case-insensitive day name (e.g., "Monday"); (3) case-insensitive, 3-character short day name (e.g., "Mon").
Warning: A DateTime definition object with day** should not be combined with year, quarter, month, or date.

hours: Option<f64>

Integer value representing the hour of a day from 0-23.

milliseconds: Option<f64>

Integer value representing the millisecond segment of time.

minutes: Option<f64>

Integer value representing the minute segment of time from 0-59.

month: Option<Month>

One of: (1) integer value representing the month from 1-12. 1 represents January; (2) case-insensitive month name (e.g., "January"); (3) case-insensitive, 3-character short month name (e.g., "Jan").

quarter: Option<f64>

Integer value representing the quarter of the year (from 1-4).

seconds: Option<f64>

Integer value representing the second segment (0-59) of a time value

utc: Option<bool>

A boolean flag indicating if date time is in utc time. If false, the date time is in local time

year: Option<f64>

Integer value representing the year.