pub struct DomainClass {
pub field: Option<String>,
pub selection: String,
pub encoding: Option<String>,
}Fields
field: Option<String>The field name to extract selected values for, when a selection is projected over multiple fields or encodings.
selection: StringThe name of a selection.
encoding: Option<String>The encoding channel to extract selected values for, when a selection is projected over multiple fields or encodings.