ProjectionConfig

Struct ProjectionConfig 

pub struct ProjectionConfig {
Show 15 fields pub center: Option<Vec<f64>>, pub clip_angle: Option<f64>, pub clip_extent: Option<Vec<Vec<f64>>>, pub coefficient: Option<f64>, pub distance: Option<f64>, pub fraction: Option<f64>, pub lobes: Option<f64>, pub parallel: Option<f64>, pub precision: Option<HashMap<String, PrecisionValue>>, pub radius: Option<f64>, pub ratio: Option<f64>, pub rotate: Option<Vec<f64>>, pub spacing: Option<f64>, pub tilt: Option<f64>, pub projection_config_type: Option<VgProjectionType>,
}
Projection configuration, which determines default properties for all projections. For a full list of projection configuration options, please see the corresponding section of the projection documentation.

Any property of Projection can be in config

Fields

center: Option<Vec<f64>>

Sets the projection’s center to the specified center, a two-element array of longitude and latitude in degrees.

Default value: [0, 0]

clip_angle: Option<f64>

Sets the projection’s clipping circle radius to the specified angle in degrees. If null, switches to antimeridian cutting rather than small-circle clipping.

clip_extent: Option<Vec<Vec<f64>>>

Sets the projection’s viewport clip extent to the specified bounds in pixels. The extent bounds are specified as an array [[x0, y0], [x1, y1]], where x0 is the left-side of the viewport, y0 is the top, x1 is the right and y1 is the bottom. If null, no viewport clipping is performed.

coefficient: Option<f64>distance: Option<f64>fraction: Option<f64>lobes: Option<f64>parallel: Option<f64>precision: Option<HashMap<String, PrecisionValue>>

Sets the threshold for the projection’s adaptive resampling to the specified value in pixels. This value corresponds to the Douglas–Peucker distance. If precision is not specified, returns the projection’s current resampling precision which defaults to √0.5 ≅ 0.70710….

radius: Option<f64>ratio: Option<f64>rotate: Option<Vec<f64>>

Sets the projection’s three-axis rotation to the specified angles, which must be a two- or three-element array of numbers [lambda, phi, gamma] specifying the rotation angles in degrees about each spherical axis. (These correspond to yaw, pitch and roll.)

Default value: [0, 0, 0]

spacing: Option<f64>tilt: Option<f64>projection_config_type: Option<VgProjectionType>

The cartographic projection to use. This value is case-insensitive, for example "albers" and "Albers" indicate the same projection type. You can find all valid projection types in the documentation.

Default value: mercator