SelectionConfig

Struct SelectionConfig 

pub struct SelectionConfig {
    pub interval: Option<IntervalSelectionConfig>,
    pub multi: Option<MultiSelectionConfig>,
    pub single: Option<SingleSelectionConfig>,
}
An object hash for defining default properties for each type of selections.

Fields

interval: Option<IntervalSelectionConfig>

The default definition for an interval selection. All properties and transformations for an interval selection definition (except type) may be specified here.

For instance, setting interval to {"translate": false} disables the ability to move interval selections by default.

multi: Option<MultiSelectionConfig>

The default definition for a multi selection. All properties and transformations for a multi selection definition (except type) may be specified here.

For instance, setting multi to {"toggle": "event.altKey"} adds additional values to multi selections when clicking with the alt-key pressed by default.

single: Option<SingleSelectionConfig>

The default definition for a single selection. All properties and transformations for a single selection definition (except type) may be specified here.

For instance, setting single to {"on": "dblclick"} populates single selections on double-click by default.