pub enum DomainUnion {
DomainClass(DomainClass),
Enum(Domain),
UnionArray(Vec<SortElement>),
}Expand description
Customized domain values.
For quantitative fields, domain can take the form of a two-element array with minimum
and maximum values. Piecewise
scales can be created by
providing a domain with more than two entries.
If the input field is aggregated, domain can also be a string value "unaggregated",
indicating that the domain should include the raw data values prior to the aggregation.
For temporal fields, domain can be a two-element array minimum and maximum values, in
the form of either timestamps or the DateTime definition
objects.
For ordinal and nominal fields, domain can be an array that lists valid input
values.
The selection property can be used to interactively
determine the scale
domain.
Variants