pub struct IntervalSelectionConfig {
pub bind: Option<BindEnum>,
pub empty: Option<VgLayoutAlign>,
pub encodings: Option<Vec<SingleDefChannel>>,
pub fields: Option<Vec<String>>,
pub mark: Option<BrushConfig>,
pub on: Option<Value>,
pub resolve: Option<SelectionResolution>,
pub translate: Option<Translate>,
pub zoom: Option<Translate>,
}Expand description
The default definition for an
interval selection. All
properties and transformations
for an interval selection definition (except type) may be specified here.
For instance, setting interval to {"translate": false} disables the ability to move
interval selections by default.
Fields
bind: Option<BindEnum>Establishes a two-way binding between the interval selection and the scales used within the same view. This allows a user to interactively pan and zoom the view.
empty: Option<VgLayoutAlign>By default, all data values are considered to lie within an empty selection.
When set to none, empty selections contain no data values.
encodings: Option<Vec<SingleDefChannel>>An array of encoding channels. The corresponding data field values must match for a data tuple to fall within the selection.
fields: Option<Vec<String>>An array of field names whose values must match for a data tuple to fall within the selection.
mark: Option<BrushConfig>An interval selection also adds a rectangle mark to depict the
extents of the interval. The mark property can be used to customize the
appearance of the mark.
on: Option<Value>A Vega event stream (object or selector) that triggers the selection. For interval selections, the event stream must specify a start and end.
resolve: Option<SelectionResolution>With layered and multi-view displays, a strategy that determines how selections’ data queries are resolved when applied in a filter transform, conditional encoding rule, or scale domain.
translate: Option<Translate>When truthy, allows a user to interactively move an interval selection
back-and-forth. Can be true, false (to disable panning), or a
Vega event stream definition
which must include a start and end event to trigger continuous panning.
Default value: true, which corresponds to
[mousedown, window:mouseup] > window:mousemove! which corresponds to
clicks and dragging within an interval selection to reposition it.
zoom: Option<Translate>When truthy, allows a user to interactively resize an interval selection.
Can be true, false (to disable zooming), or a Vega event stream
definition. Currently,
only wheel events are supported.
Default value: true, which corresponds to wheel!.